==> devextreme-22.1.3.tgz: package/cjs/renovation/utils/plugin/placeholder_extender.j.js <==
/**
 * DevExtreme (cjs/renovation/utils/plugin/placeholder_extender.j.js)
 * Version: 22.1.3
 * Build date: Mon Jun 13 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../component_wrapper/common/component"));
var _placeholder_extender = require("./placeholder_extender");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var PlaceholderExtender = function(_BaseComponent) {
    _inheritsLoose(PlaceholderExtender, _BaseComponent);

    function PlaceholderExtender() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(PlaceholderExtender, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["template"],
                props: ["type", "order", "template", "deps"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _placeholder_extender.PlaceholderExtender
        }
    }]);
    return PlaceholderExtender
}(_component.default);
exports.default = PlaceholderExtender;
(0, _component_registrator.default)("dxPlaceholderExtender", PlaceholderExtender);
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-22.1.4.tgz: package/cjs/renovation/utils/plugin/placeholder_extender.j.js <==
/**
 * DevExtreme (cjs/renovation/utils/plugin/placeholder_extender.j.js)
 * Version: 22.1.4
 * Build date: Fri Jul 22 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _component_registrator = _interopRequireDefault(require("../../../core/component_registrator"));
var _component = _interopRequireDefault(require("../../component_wrapper/common/component"));
var _placeholder_extender = require("./placeholder_extender");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    Object.defineProperty(Constructor, "prototype", {
        writable: false
    });
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var PlaceholderExtender = function(_BaseComponent) {
    _inheritsLoose(PlaceholderExtender, _BaseComponent);

    function PlaceholderExtender() {
        return _BaseComponent.apply(this, arguments) || this
    }
    _createClass(PlaceholderExtender, [{
        key: "_propsInfo",
        get: function() {
            return {
                twoWay: [],
                allowNull: [],
                elements: [],
                templates: ["template"],
                props: ["type", "order", "template", "deps"]
            }
        }
    }, {
        key: "_viewComponent",
        get: function() {
            return _placeholder_extender.PlaceholderExtender
        }
    }]);
    return PlaceholderExtender
}(_component.default);
exports.default = PlaceholderExtender;
(0, _component_registrator.default)("dxPlaceholderExtender", PlaceholderExtender);
module.exports = exports.default;
module.exports.default = exports.default;
